@@ -20,7 +20,7 @@ if( any( inherits( obj, c("coxph","glm","gls","lm","nls","survreg","clogistic","
 } else if( inherits( obj, c("lme") ) ) {
        cf <- fixed.effects( obj )
       vcv <- vcov( obj )
-} else if( inherits( obj, c("mer") ) ) {
+} else if( inherits( obj, c("mer","lmerMod") ) ) {
        cf <- fixef( obj )
       vcv <- as.matrix( vcov( obj ) )
 } else if (inherits(obj, "MIresult")) {
@@ -35,6 +35,9 @@ if( any( inherits( obj, c("coxph","glm","gls","lm","nls","survreg","clogistic","
 } else if( inherits( obj, "gnlm" ) ) {
        cf <- coef( obj )
       vcv <- obj$cov
+} else if( inherits( obj, "rq" ) ) {
+       cf <- coef( obj )
+      vcv <- summary( obj, cov=TRUE )$cov
 } else stop( "\"", deparse( substitute( obj ) ), "\" is of class \"",
               class( obj ), "\" which is not supported." )
 
@@ -175,7 +178,7 @@ if( !diffs )
     if( sample ) res <- t( mvrnorm( sample, ct, vc ) ) else {
     se <- sqrt( diag( vc ) )
     ci <- cbind( ct, se ) %*% ci.mat( alpha=alpha, df=df )
-    t0 <- cbind( se, ct/se, 2 * ( 1 - pnorm( abs( ct / se ) ) ) )
+    t0 <- cbind( se, ct/se, 2 * ( pnorm( -abs( ct / se ) ) ) )
     colnames(t0) <- c("StdErr", "z", "P")
     res <- cbind(ci, t0)[, c(1, 4:6, 2:3), drop=FALSE]
     if( Exp )
