@@ -1,6 +1,7 @@
 Lexis <-
 function(entry, exit, duration, entry.status=0, exit.status=0, id, data,
-         merge=TRUE, states, tol=.Machine$double.eps^0.5)
+         merge=TRUE, states, tol=.Machine$double.eps^0.5,
+         keep.dropped=FALSE )
 {
   nmissing <- missing(entry) + missing(exit) + missing(duration)
   if (nmissing > 2)
@@ -176,10 +177,11 @@ function(entry, exit, duration, entry.status=0, exit.status=0, id, data,
       stop("Duration is not the same on all time scales")
     }
   }
-  ## Check that duration is positive
-  if (any(duration<0)) {
-    stop("Duration must be non-negative")
-  }
+#  Taken care of by the code that detects whether lex.du <= tol
+#  ## Check that duration is positive
+#  if (any(duration<0)) {
+#    stop("Duration must be non-negative")
+#  }
 
   ## Make sure id value - if supplied - is valid. Otherwise supply default id
 
@@ -219,16 +221,22 @@ function(entry, exit, duration, entry.status=0, exit.status=0, id, data,
     lex <- cbind(lex, data)
   }
 
-  ## Drop rows with short duration for consistency with splitLexis
+  ## Drop rows with short or negantive duration for consistency with splitLexis
   short.dur <- lex$lex.dur <= tol
-  if (any(short.dur)) {
+  if ( any(short.dur) ) {
       warning("Dropping ", sum(short.dur),
-              " rows with duration of follow up < tol")
+              " rows with duration of follow up < tol\n",
+      if( keep.dropped ) "  The dropped rows are in the attribute 'dropped'\n",
+      if( keep.dropped ) "  To see them type attr(Obj,'dropped'),\n",
+      if( keep.dropped ) "  to get rid of them type attr(Obj,'dropped') <- NULL\n",
+      if( keep.dropped ) "  - where 'Obj' is the name of your Lexis object" )
       lex <- subset(lex, !short.dur)
-  }
+      if( keep.dropped ) attr(lex,"dropped") <- subset(data, short.dur)
+      }
 
   ## Return Lexis object
   attr(lex,"time.scales") <- all.time.scales
+  attr(lex,"time.since") <- rep( "", length(all.time.scales) )
   breaks <- vector("list", length(all.time.scales))
   names(breaks) <- all.time.scales
   attr(lex,"breaks") <- breaks
@@ -244,12 +252,12 @@ is.Lexis <- function(x)
 check.time.scale <- function(lex, time.scale=NULL)
 {
 
-  ##Utility function, returns the names of the time scales in a Lexis object
-  ##lex - a Lexis object
-  ##time.scale - a numeric or character vector. The function checks that
-  ##             these are valid time scales for the Lexis object.
-  ##Return value is a character vector containing the  names of the requested
-  ##time scales
+  ## Utility function, returns the names of the time scales in a Lexis object
+  ## lex - a Lexis object
+  ## time.scale - a numeric or character vector. The function checks that
+  ##              these are valid time scales for the Lexis object.
+  ## Return value is a character vector containing the  names of the requested
+  ## time scales
 
   all.names <- timeScales(lex)
   if (is.null(time.scale))
@@ -260,12 +268,12 @@ check.time.scale <- function(lex, time.scale=NULL)
   if (is.character(time.scale)) {
     for (i in 1:nscale) {
       if (is.null(lex[[time.scale[i]]]))
-        stop("invalid time scale name")
+        stop(time.scale[i], " is not a valid time scale name")
     }
   }
   else if (is.numeric(time.scale)) {
     if (any(time.scale > length(all.names))  || any(time.scale < 1))
-      stop("invalid time scale column number")
+      stop(time.scale, " not valid time scale column number(s)")
     time.scale <- all.names[time.scale]
   }
   else {
@@ -519,6 +527,7 @@ subset.Lexis <- function(x, ...)
   y <-  subset.data.frame(x, ...)
   attr(y,"breaks") <- attr(x, "breaks")
   attr(y,"time.scales") <- attr(x, "time.scales")
+  attr(y,"time.since") <- attr(x, "time.since")
   return(y)
 }
 
@@ -553,6 +562,7 @@ merge.Lexis <- function(x, y, id, by, ...)
   z <-  base::merge.data.frame(x, y, ...)
   attr(z,"breaks") <- attr(x, "breaks")
   attr(z,"time.scales") <- attr(x, "time.scales")
+  attr(z,"time.since") <- attr(x, "time.since")
   class(z) <- c("Lexis", "data.frame")
   return(z)
 }
@@ -567,7 +577,7 @@ entry <- function(x, time.scale = NULL, by.id = FALSE )
      ave( x[,time.scale[1]], x$lex.id, FUN=if( by.id ) min else I )
     if (length(time.scale) > 1) {
         res <- as.matrix(x[wh, time.scale])
-        if( by.id ) colnames( res ) <- x$lex.id[wh]
+        if( by.id ) rownames( res ) <- x$lex.id[wh]
         return( res )
     }
     else {
@@ -667,7 +677,7 @@ transform.Lexis <- function(`_data`, ... )
     save.at <- attributes(`_data`)
     ## We can't use NextMethod here because of the special scoping rules
     ## used by transform.data.frame
-    y <- base:::transform.data.frame(`_data`, ...)
+    y <- base::transform.data.frame(`_data`, ...)
     save.at[["names"]] <- attr(y, "names")
     attributes(y) <- save.at
     y
